# __all__ = [
#     # warnings
#     # exceptions
#     'KJException',
#     'NeedLoginException',
# ]


class KJException(Exception):
    pass


class NeedLoginException(KJException):
    def __init__(self, what):
        """
        使用某方法需要登录而当前客户端未登录

        :param str|unicode what: 当前试图调用的方法名
        """
        self.what = what

    def __repr__(self):
        return '需要登录才能使用 [{self.what}] 方法。'.format(self=self)

    __str__ = __repr__


class NeedAccessTokenException(KJException):

    def __repr__(self):
        return '需要用户 access-token 才能使用这个接口！'.format(self=self)

    __str__ = __repr__


class LoginError(KJException):
    """
    所有登录中发生的错误
    """



import os
import json
import time
import datetime
import random
import urllib3
from urllib3.exceptions import InsecureRequestWarning
import functools

import requests
import requests.adapters
from requests.exceptions import ConnectTimeout, ConnectionError, ProxyError
from loguru import logger

from .exception import NeedLoginException

RETRY = requests.adapters.Retry(
    total=3,  # 允许的重试总次数，优先于其他计数
    read=3,  # 重试读取错误的次数
    connect=3,  # 重试多少次与连接有关的错误（请求发送到远程服务器之前引发的错误）
    backoff_factor=0.3,  # 休眠时间： {backoff_factor} * (2 ** ({重试总次数} - 1))
    status_forcelist=[403, 408, 500, 502, 504],  # 强制重试的状态码
)

# 重试次数
DEFAULT_RETRIES = 2


def dict_to_pretty_string_py(the_dict):
    if not the_dict:
        return "{}"
    return json.dumps(the_dict, sort_keys=True, indent=4, separators=(',', ': '))


def need_login(func):
    """
    装饰器。作用于 :class:`.DouYinAPI` 中的某些方法，
    强制它们必须在登录状态下才能被使用。
    """

    @functools.wraps(func)
    def wrapper(self, *args, **kwargs):
        if self.is_login():
            return func(self, *args, **kwargs)
        else:
            raise NeedLoginException(func.__name__)

    return wrapper


def random_sleep(start=1, end=3, debug=True):
    """
    随机延迟，因为如果你访问了很多页面，你的 ip 可能会被封。
    """
    sleep_time = random.randint(start, end)
    if debug:
        print('随机延迟：%s 秒......' % sleep_time)
    time.sleep(sleep_time)


def get_now(fmt="%Y-%m-%d %H:%M:%S"):
    """
    获取当前日期和时间
    :return: 格式 2018-11-28 15:03:08
    """
    return datetime.datetime.now().strftime(fmt)


def second_to_time_str(seconds):
    """
    秒转换为人类阅读的时间显示，用来显示已用时间
    例如：'1小时1分1.099秒'
    """
    time_str = ''
    hour = '%01d小时' % (seconds / 3600)
    minute = '%01d分' % ((seconds % 3600) / 60)

    if hour != '0小时':
        time_str += hour

    if minute != '0分':
        time_str += minute

    # seconds
    time_str += '%01d.%03d秒' % (seconds % 60, (seconds % 1) * 1000)

    return time_str


class Timer:
    """
    计时器，可以当装饰器或者用 with 来对代码计时

    # 例子：
        >>> import time
        >>> def papapa(t):
        >>>     time.sleep(t)
        >>> with Timer() as timer:
        >>>     papapa(1)
        运行时间 1.000 秒
        >>> @Timer.time_it
        >>> def papapa(t):
        >>>     time.sleep(t)
        >>> papapa(1)
        papapa 运行时间 1.001 秒
    """

    def __init__(self, name=None):
        self.start = time.time()

        # 我们添加一个自定义的计时名称
        if isinstance(name, str):
            self.name = name + ' '
        else:
            self.name = ''

        print(f'{get_now()} 开始运行 {self.name}', )

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.running_time()
        return exc_type is None

    @staticmethod
    def time_it(func):
        def wrapper(*args, **kwargs):
            start = time.time()
            print(f'{get_now()} 开始运行 {func.__name__}', )
            result = func(*args, **kwargs)
            print(f'{get_now()} 结束运行 {func.__name__}，运行时间 {second_to_time_str(time.time() - start)}', )
            return result

        return wrapper

    def running_time(self):
        stop = time.time()
        cost = stop - self.start
        print(f'{get_now()} 结束运行 {self.name}，运行时间 {second_to_time_str(cost)}', )


class BaseClient:
    def __init__(self, retry=None, retries=None):
        """
        API接口的基础类

        # 来自
        >>> from spider_utils.client import BaseSpiderClient

        """
        self._session = requests.session()

        # 默认超时时间 https://2.python-requests.org//zh_CN/latest/user/advanced.html#timeout
        self.timeout = 5

        # 重试次数
        if retries is None:
            self.retries = DEFAULT_RETRIES
        else:
            self.retries = retries

        self.params = {}
        self.parse_data = {}
        self.load_count = 0

        # 删除SSL验证
        self._session.verify = False
        urllib3.disable_warnings(InsecureRequestWarning)

        # 添加会话自动重试
        if retry is None:
            adapter_with_retry = requests.adapters.HTTPAdapter(max_retries=RETRY)
        else:
            adapter_with_retry = requests.adapters.HTTPAdapter(max_retries=retry)
        self._session.mount('http://', adapter_with_retry)
        self._session.mount('https://', adapter_with_retry)

    def set_proxy(self, proxy):
        """ 设置 http 和 https 代理或者 sock5代理（requests 已经可以支持 socks 代理）

        因为由 :any:`SpiderClient` 生成的爬虫类对象和本对象使用同一session，
        所以设置代理后，对所有由当前对象生成的爬虫对象均会使用设置的代理。

        ..  note:: 如果需要使用 socks 代理，需要安装 pysocks

            ``sudo pip install pysocks>=1.5.6,!=1.5.7``

        :param str|unicode proxy: 形如 'http://user:pass@10.10.1.10:3128/'
          或者 'socks5://user:pass@host:port'。
          传入 None 表示清除代理设置。
        :return: None
        """
        if proxy is None:
            self._session.proxies.clear()
        else:
            self._session.proxies.update({'http': proxy, 'https': proxy})

    def set_headers(self, headers):
        """
        设置 headers（全局），如果是 None，清除数据

        :return: None
        """
        if headers is None:
            self._session.headers.clear()
        else:
            self._session.headers.update(headers)

    def get_headers(self):
        """
        获取 headers（全局）

        :return: Dict(headers)
        """
        return dict(self._session.headers)

    def set_cookies(self, cookies):
        """
        设置 cookies（全局），如果是 None，清除数据

        :return: None
        """
        if cookies is None:
            self._session.cookies.clear()
        else:
            self._session.cookies.update(cookies)

    def get_cookies(self):
        """
        获取 cookies（全局）

        :return: Dict(cookies)
        """
        return requests.utils.dict_from_cookiejar(self._session.cookies)

    def set_params(self, params):
        """
        设置 params（全局），如果是 None，清除数据

        :return: None
        """
        if params is None:
            self.params = {}
        else:
            self.params.update(params)

    def get(self, url, **kwargs):
        r"""发送GET请求。 返回响应对象。

        :param url: URL for the new :class:`Request` object.
        :param \*\*kwargs: Optional arguments that ``request`` takes.
        :rtype: requests.Response
        """
        kwargs.setdefault('timeout', self.timeout)

        # 合并 params
        params = dict(self.params)
        if 'params' in kwargs:
            params.update(kwargs['params'])
            del kwargs['params']

        return self._session.get(url, params=params, **kwargs)

    def download(self, url, dst, **kwargs):
        """
        下载文件
        """

        req = self.get(url, **kwargs)

        with open(dst, 'ab') as f:
            f.write(req.content)

        file_size = os.path.getsize(dst)
        # 检查文件大小判断是否下载成功
        if file_size >= int(req.headers['content-length']):
            return file_size
        else:
            os.remove(dst)

    def load_page(self, url, **kwargs):

        self.parse_data = {}
        self.load_count += 1
        logger.info(f'[{self.load_count:05}] Starting {url}')

        for i in range(self.retries):
            try:
                r = self.get(url, **kwargs)
                random_sleep()
            except (ConnectTimeout, ConnectionError) as e:
                logger.warning(str(e))
            else:
                return r

    def api(self, method, url, params=None, data=None):
        """
        开发时用的测试某个 API 返回的 JSON 用的便捷接口。

        :param str|unicode method: HTTP 方式， GET or POST or OPTION, etc。
        :param str|unicode url: API 地址。
        :param dict params: GET 参数。
        :param dict data: POST 参数。
        :return: 访问结果。
        :rtype: request.Response
        """
        return self._session.request(method, url, params, data)

    def __repr__(self):
        repr_info = [f"<------------------------------ {type(self).__name__} ------------------------------>",
                     f"timeout = {self.timeout}",
                     f"headers = {dict_to_pretty_string_py(self.get_headers())}",
                     f"cookies = {dict_to_pretty_string_py(self.get_cookies())}",
                     f"params = {dict_to_pretty_string_py(self.params)}",
                     f"<------------------------------ {type(self).__name__} ------------------------------>"]
        return '\n'.join(repr_info)



"""
我们保存接口获取的字段信息，用来比较是否有新增或者减少
"""
PERSONAL_CENTER_MY_DETAIL_FIELDS = {
    'avatar': '头像',
    'certificateValidity': '_certificateValidity',
    'code': '_code',
    'companies': '_companies',  # json
    'companiesCp': '_companiesCp',
    'createUid': '用户创建ID',
    'ctime': '用户创建时间',
    'depts': 'depts',  # json
    'email': '邮箱',
    'enableStatus': '_enableStatus',
    'groupAlias': '_groupAlias',
    'groupName': '_groupName',
    'introduction': '_introduction',
    'lastCommitCertInfoTime': '_lastCommitCertInfoTime',
    'lastLoginTime': '_lastLoginTime',
    'name': '真实姓名',
    'orgCp': '_orgCp',  # json
    'orgId': '_orgId',
    'orgName': '所属部门',
    'orgVo': '_orgVo',  # json
    'passwordComplex': '_passwordComplex',
    'phone': '手机号码',
    'relName': '常用名',
    'roles': '用户角色',  # json
    'sex': '性别',
    'signature': '_signature',
    'sourceType': '_sourceType',
    'type': '_type',
    'updateUid': '更新用户ID',
    'updateUname': '更新用户名字',
    'username': '用户名',
    'utime': '用户更新时间',
    'wxNumber': '微信号',
    # 20250415 删除
    # 'user_id': '用户ID',
    # 20250415 添加
    'id': '用户ID',
    'inviteCode': '_inviteCode',
}

# 供应商结算单详情
SETTLEMENT_INFO_LIST_FIELDS = {
    'attachmentFiles': '附件文件',
    'cname': '创建者',
    'code': '供应商结算单ID',
    'contractCode': '内部合同编号Code',
    'contractId': '内部合同编号ID',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司',
    'cpId': '所属公司ID',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'endTime': '结束时间',
    'frozenStatus': '冻结状态',
    'id': '结算单ID',
    'isCanApprove': '可以审核',
    'liableManName': '负责人名字',
    'name': '名字',
    'ogTotleAmount': '原始分成总计',
    'settlementCurrency': '结算货币',
    'settlementCurrencyStr': '结算货币名字',
    'spDisplayName': '结算渠道',
    'spId': '结算渠道ID',
    'spName': '结算渠道',
    'startTime': '开始时间',
    'status': '当前状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名称',
    'supplierId': '供应商名称ID',
    'supplierName': '供应商名称',
    'totleAmount': '实际分成总计',
    'uname': '操作用户',
    'utime': '操作时间',
    # 后面添加的
    'deDeposit': '_deDeposit',
    'deOtherAmount': '_deOtherAmount',
    'shareProportion': '_shareProportion',
    'exchangeRate': '_exchangeRate',
    'divideType': '_divideType',
    'divisionMethod': '_divisionMethod',
    # 20241101 添加的内容
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个时间间隔的文本列表
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'shareBeginDate': '_shareBeginDate',
    'shareEndDate': '_shareEndDate',
    'divisionRuleId': '_divisionRuleId',
    # 2025-04-15 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 供应商结算单详情
SETTLEMENT_INFO_FIELDS = {
    'attachmentFiles': '附件文件',
    'cname': '创建者',
    'code': '供应商结算单号',
    'contractCode': '合同Code',
    'contractId': '合同ID',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethod': '合作模式Id',
    'endTime': '结算结束时间',
    'frozenStatus': '冻结状态',
    'id': '供应商结算单ID',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '名字',
    'ogTotleAmount': '原始分成总计',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'status': '当前状态ID',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 后面添加的
    'exchangeRate': '_exchangeRate',
    'divideType': '_divideType',
    'currentSettInfo': '_currentSettInfo',
    'innerInfos': '_innerInfos',
    # 20241101 删除的内容
    # 'divisionMethodName': '合作模式名字',
    # 'relationSupplierDocCode': '_relationSupplierDocCode',
    # 'relationSupplierDocId': '_relationSupplierDocId',
    # 'settleFormula': '结算公式',
    # 20241101 添加的内容
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'divisionRuleId': '_divisionRuleId',
    # 2025-04-15 删除
    # 'exchRateDetail': '_exchRateDetail',
    # 2025-04-15 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
    'negativeSettleAmount': '_negativeSettleAmount',

}

# 采购合约列表
CP_CONTRACT_LIST_FIELDS = {
    'attachmentFiles': '附件文件数据',  # 列表数据
    'attachmentType': '附件文件类型',  # 列表
    'authName': '他方签约主体全称',
    'authOrgDisplayName': '他方签约主体显示名称',
    'authOrgId': '他方签约主体',
    'authOrgName': '他方签约主体常用名',
    'authOrgType': '他方签约主体类型',
    'authScope': '_authScope',
    'brandCode': '所属厂牌CODE',
    'brandDisplayName': '所属厂牌显示名称',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'cid': '创建者ID',
    'cname': '创建者',
    'code': '合约CODE',
    'companyId': '_companyId',
    'contactsAddress': 'CP联系人地址',
    'contactsEmail': 'CP联系人邮箱',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '合约截止时间',
    'contractProperty': '合约属性',
    'contractPutOffM': '_contractPutOffM',
    'contractPutOffY': '_contractPutOffY',
    'contractStopMode': '_contractStopMode',
    'ctime': '创建时间',
    'dataSourceType': '_dataSourceType',
    'demoCopyrightType': '_demoCopyrightType',  # 列表
    'effectiveRemark': '_effectiveRemark',
    'explain': '合约说明',
    'fileId': '文件ID',
    'id': '合约ID',  # 改为 cp_id
    'identification': '_identification',
    'isCanApprove': '可以审核',
    'liableManEmail': '负责人邮箱',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人',
    'liableManPhone': '负责人电话',
    'listStatus': '_listStatus',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'orgType': '_orgType',
    'originAuthName': '原始授权方全称',
    'originAuthOrgDisplayName': '原始授权方显示名称',
    'originAuthOrgId': '原始授权方ID',
    'originAuthOrgName': '原始授权方名称',
    'originAuthOrgType': '原始授权方类型',
    'otherAuthOrgs': '其他授权方数据',  # 列表数据
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'ourSignOrgId': '我方签约主体ID',
    'ourSignOrgName': '我方签约主体',
    'outContractNo': '外部合约编号',
    'productActualCount': '实际歌曲数',
    'productCount': '合约歌曲数',
    'relationContractExplain': '_relationContractExplain',
    'relationContractNo': '_relationContractNo',
    'signTime': '合约签署时间',
    'status': '合约状态',
    'type': '合约类型',  # 列表
    'uid': '更新用户ID',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 添加的内容
    'ourSignName': '_ourSignName',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'cpBeginEndTime': '_cpBeginEndTime',
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个文本列表
    # 2025-04-15 添加
    'lockStatus': '_lockStatus',
    'minPayAmount': '_minPayAmount',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 采购合约详情
CP_CONTRACT_FIELDS = {
    'attachmentFiles': '附件文件数据',  # 列表数据
    'attachmentType': '附件文件类型',  # 列表
    'authName': '他方签约主体全称',
    'authOrgDisplayName': '他方签约主体显示名称',
    'authOrgId': '他方签约主体',
    'authOrgName': '他方签约主体常用名',
    'authOrgType': '他方签约主体类型',
    'authScope': '_authScope',
    'brandCode': '所属厂牌CODE',
    'brandDisplayName': '所属厂牌显示名称',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'cid': '创建者ID',
    'cname': '创建者',
    'code': '合约CODE',
    'companyId': '_companyId',
    'contactsAddress': 'CP联系人地址',
    'contactsEmail': 'CP联系人邮箱',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '合约截止时间',
    'contractProperty': '合约属性',
    'contractPutOffM': '_contractPutOffM',
    'contractPutOffY': '_contractPutOffY',
    'contractStopMode': '_contractStopMode',
    'ctime': '创建时间',
    'dataSourceType': '_dataSourceType',
    'demoCopyrightType': '_demoCopyrightType',  # 列表
    'effectiveRemark': '_effectiveRemark',
    'explain': '合约说明',
    'fileId': '文件ID',
    'id': '合约ID',  # 改为 cp_id
    'identification': '_identification',
    'isCanApprove': '可以审核',
    'liableManEmail': '负责人邮箱',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人',
    'liableManPhone': '负责人电话',
    'listStatus': '_listStatus',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'orgType': '_orgType',
    'originAuthName': '原始授权方全称',
    'originAuthOrgDisplayName': '原始授权方显示名称',
    'originAuthOrgId': '原始授权方ID',
    'originAuthOrgName': '原始授权方名称',
    'originAuthOrgType': '原始授权方类型',
    'otherAuthOrgs': '其他授权方数据',  # 列表数据
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'ourSignOrgId': '我方签约主体ID',
    'ourSignOrgName': '我方签约主体',
    'outContractNo': '外部合约编号',
    'productActualCount': '实际歌曲数',
    'productCount': '合约歌曲数',
    'relationContractExplain': '_relationContractExplain',
    'relationContractNo': '_relationContractNo',
    'signTime': '合约签署时间',
    'status': '合约状态',
    'type': '合约类型',  # 列表
    'uid': '更新用户ID',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 添加的内容
    'ourSignName': '_ourSignName',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'cpBeginEndTime': '_cpBeginEndTime',
    'divisionMethodNames': '合作模式名字列表',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个文本列表
    'shareBeginEndTimes': '分成起止时间',  # 内容是一个文本列表
    # 2025-04-15 添加
    'lockStatus': '_lockStatus',
    'minPayAmount': '_minPayAmount',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'negativeSettleAmount': '_negativeSettleAmount',
}

# 采购合约-版权信息
CP_CONTRACT_DETAIL_COPYRIGHT_FIELDS = {
    'id': '版权信息ID',
    'relationId': '_relationId',
    'relationType': '_relationType',
    'contractStartDate': '授权开始时间',
    'contractEndDate': '授权结束时间',
    'contractExpireDealType': '_contractExpireDealType',
    'contractExtension': '_contractExtension',
    'authChannelType': '_authChannelType',
    'authRegionType': '_authRegionType',
    'contractAttr': '_contractAttr',
    'generalAgent': '_generalAgent',
    'overseasGeneralAgent': '_overseasGeneralAgent',
    'safeguardLegitimate': '_safeguardLegitimate',
    'allowClip': '_allowClip',
    'allowCover': '_allowCover',
    'coverNeedOwnerAllow': '_coverNeedOwnerAllow',
    'coverStartDate': '_coverStartDate',
    'coverEndDate': '_coverEndDate',
    'contractSource': '_contractSource',
    'contractRemarks': '_contractRemarks',
    'authBeginTime': '_authBeginTime',
    'authEndTime': '_authEndTime',
    'authLeftDays': '_authLeftDays',
    'sublicense': '_sublicense',
    'authRightType': '_authRightType',
    'customAuthRight': '_customAuthRight',
    'contractAttrAddition': '_contractAttrAddition',
    'generalAgentRemark': '_generalAgentRemark',
    'safeguardLegitimateRemark': '_safeguardLegitimateRemark',
    'allowClipRemark': '_allowClipRemark',
    'allowCoverRemark': '_allowCoverRemark',
    'sublicenseRemark': '_sublicenseRemark',
    'adapt': '_adapt',
    'adaptRemark': '_adaptRemark',
    'contractAttrAdditionType': '_contractAttrAdditionType',
    'customContractAttrAddition': '_customContractAttrAddition',
    'contractExtensionYear': '_contractExtensionYear',
    'contractExtensionMonth': '_contractExtensionMonth',
    'copyrightRightsIds': '_copyrightRightsIds',
    'copyrightRightsIdsForFront': '_copyrightRightsIdsForFront',
    'userTypes': '_userTypes',
    'copyrightBusinessIds': '_copyrightBusinessIds',
    'authChannelSpIds': '_authChannelSpIds',
    'authChannels': '_authChannels',
    'authRegionIds': '_authRegionIds',
    'continent': '_continent',
    'authRegions': '_authRegions',
    'assetTypes': '_assetTypes',
    'copyrightInfo': '_copyrightInfo',
}

# 采购合约-结算模式(他返回的数据是一个结算模式的列表)
CP_CONTRACT_DETAIL_SETTLEMENT_MODE_FIELDS = {
    'id': '结算模式ID',
    'contractId': '合同ID',
    'accountType': '账户类型',
    'accountName': '银行账户名',
    'accountNum': '银行账户号码',
    'bankName': '开户行',
    'settlementCycle': '结算周期',
    'settlementCurrency': '结算货币',
    'divisionRuleIds': '合作规则',
    'shareProportion': '分成比例',
    'shareBeginDate': '分成开始时间',
    'shareEndDate': '分成结束时间',
    'spType': '渠道类型',
    'copyrightType': '版权类型',
    'shareReference': '分成参照',
    'divisionMethodName': '合作模式名字',
    'divisionMethodCode': '合作模式CODE',
    'spVos': '_spVos',
    'spNames': '_spNames',
}

# 采购合约关联歌曲
CONTRACT_RELATE_SONG_FIELDS = {
    'advertPublishBeginDate': 'advertPublishBeginDate',
    'advertPublishEndDate': 'advertPublishEndDate',
    'albumCode': 'albumCode',
    'albumCopyrightOrgId': 'albumCopyrightOrgId',
    'albumCopyrightOrgName': 'albumCopyrightOrgName',
    'albumId': '专辑ID',
    'albumName': '专辑名',
    'albumSingers': '专辑演唱者列表',
    'albumStatus': 'albumStatus',
    'arrangers': 'arrangers',
    'artistIdentities': 'artistIdentities',
    'authPercentage': 'authPercentage',
    'awardRecord': 'awardRecord',
    'cd': 'cd',
    'cid': '创建者ID',
    'claimRemark': 'claimRemark',
    'clineOrgId': 'clineOrgId',
    'clineYear': 'clineYear',
    'cname': '创建者',
    'code': '歌曲CODE',
    'collectionName': 'collectionName',
    'collectionTranslatedName': 'collectionTranslatedName',
    'composers': 'composers',
    'copyFromSongId': 'copyFromSongId',
    'copyrightMark': 'copyrightMark',
    'creationBackground': 'creationBackground',
    'ctime': '创建时间',
    'customJson': 'customJson',
    'dataSourceType': 'dataSourceType',
    'dataSourceUk': 'dataSourceUk',
    'firstPublishDate': '期望上线时间',
    'hasPublicity': 'hasPublicity',
    'id': 'id',
    'introduction': 'introduction',
    'isbn': 'isbn',
    'isrc': 'isrc',
    'iswc': 'iswc',
    'langTags': 'langTags',
    'languageTagId': 'languageTagId',
    'liableManId': '合约负责人ID',
    'liableManName': '合约负责人名字',
    'lockStatus': 'lockStatus',
    'lyricCopyrightIds': 'lyricCopyrightIds',
    'lyricists': 'lyricists',
    'mainTune': 'mainTune',
    'movieName': 'movieName',
    'musicCopyrightIds': 'musicCopyrightIds',
    'name': '歌曲名称',
    'originalSingName': 'originalSingName',
    'originalSongName': 'originalSongName',
    'osSongInfo': 'osSongInfo',
    'otherTags': 'otherTags',
    'paymentPattern': 'paymentPattern',
    'plineOrgId': 'plineOrgId',
    'plineYear': 'plineYear',
    'presaleTime': 'presaleTime',
    'productOrgId': 'productOrgId',
    'publicityPaymentPattern': 'publicityPaymentPattern',
    'publishDate': 'publishDate',
    'quality': 'quality',
    'recordArtists': 'recordArtists',
    'recordCopyrightOrgName': '录音版权公司名称',
    'recordOrgId': '录音版权公司ID',
    'remixArtists': 'remixArtists',
    'saleBeginTime': 'saleBeginTime',
    'saleEndTime': 'saleEndTime',
    'salePrice': 'salePrice',
    'selfOwn': 'selfOwn',
    'sendType': 'sendType',
    'singers': '歌曲演唱者列表',
    'songSource': 'songSource',
    'sort': 'sort',
    'soundRecordingCopyrightIds': 'soundRecordingCopyrightIds',
    'source': 'source',
    'status': 'status',
    'styleTagId': 'styleTagId',
    'styleTags': 'styleTags',
    'subtitle': 'subtitle',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'trackNum': 'trackNum',
    'translatedName': 'translatedName',
    'type': 'type',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': 'uniqueName',
    'upCpSongNo': 'upCpSongNo',
    'utime': '更新时间',
    'version': '歌曲版本',
    'versionName': 'versionName',
    'visrc': '虚拟ISRC',
    # 2025-04-15 删除
    # 'distributeFlag': '_distributeFlag',
    # 2025-04-15 添加
    'supplierAuth': '_supplierAuth',
    'channelStatus': '_channelStatus',
    'reason': '_reason',
    'recordCopyrightContracts': '_recordCopyrightContracts',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',
    'musicCopyrightContracts': '_musicCopyrightContracts',
    'authOrgList': '_authOrgList',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'remark': '_remark',
    'tmeChannelId': '_tmeChannelId',
    'tmeChannelAlbumId': '_tmeChannelAlbumId',
}

# 售卖合约列表
SP_CONTRACT_LIST_FIELDS = {
    'id': 'id',
    'orgType': '_orgType',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'authOrgId': '_authOrgId',
    'type': '_type',
    'code': '合约ID',
    'status': '_status',
    'ctime': '创建时间',
    'cid': '创建者ID',
    'utime': '更新时间',
    'uid': '更新用户ID',
    'fileId': '文件ID',
    'originAuthOrgId': '原始授权方ID',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contactsEmail': 'CP联系人邮箱',
    'contactsAddress': 'CP联系人地址',
    'explain': '合约说明',
    'signTime': '合约签署时间',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '授权结束时间',
    'contractStopMode': '_contractStopMode',
    'contractPutOffY': '_contractPutOffY',
    'contractPutOffM': '_contractPutOffM',
    'authScope': '_authScope',
    'demoCopyrightType': '_demoCopyrightType',
    'contractProperty': '合约属性',
    'outContractNo': '外部合约编号',
    'relationContractNo': '_relationContractNo',
    'relationContractExplain': '_relationContractExplain',
    'ourSignOrgId': '我方签约主体ID',
    'productCount': '合约歌曲数',
    'productActualCount': '实际歌曲数',
    'dataSourceType': '_dataSourceType',
    'attachmentType': '附件文件类型',  # 列表
    'liableManId': '负责人ID',
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'liableManPhone': '负责人电话',
    'liableManEmail': '负责人邮箱',
    'liableManName': '合约负责人名字',
    'companyId': '_companyId',
    'effectiveRemark': '_effectiveRemark',
    'identification': '_identification',
    'lockStatus': '_lockStatus',
    'authOrgName': '原始授权方名称',
    'cname': '创建者',
    'uname': '更新用户',
    'fileName': '文件名',
    'ourMainSignOrgName': '_ourMainSignOrgName',
    'ourSignName': '_ourSignName',
    'attachmentFiles': '附件文件数据',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'brandDisplayName': '所属厂牌显示名称',
    'brandCode': '所属厂牌CODE',
}

# 售卖合约详情
SP_CONTRACT_FIELDS = {
    'id': 'id',
    'orgType': '_orgType',
    'name': '合约名称',
    'offlineCode': '内部合约编号',
    'authOrgId': '_authOrgId',
    'type': '_type',
    'code': '合约ID',
    'status': '_status',
    'ctime': '创建时间',
    'cid': '创建者ID',
    'utime': '更新时间',
    'uid': '更新用户ID',
    'fileId': '文件ID',
    'originAuthOrgId': '原始授权方ID',
    'contactsName': 'CP指定联系人',
    'contactsPhone': 'CP联系人电话',
    'contactsEmail': 'CP联系人邮箱',
    'contactsAddress': 'CP联系人地址',
    'explain': '合约说明',
    'signTime': '合约签署时间',
    'contractBeginDate': '合约生效时间',
    'contractEndDate': '授权结束时间',
    'contractStopMode': '_contractStopMode',
    'contractPutOffY': '_contractPutOffY',
    'contractPutOffM': '_contractPutOffM',
    'authScope': '_authScope',
    'demoCopyrightType': '_demoCopyrightType',
    'contractProperty': '合约属性',
    'outContractNo': '外部合约编号',
    'relationContractNo': '_relationContractNo',
    'relationContractExplain': '_relationContractExplain',
    'ourSignOrgId': '我方签约主体ID',
    'productCount': '合约歌曲数',
    'productActualCount': '实际歌曲数',
    'dataSourceType': '_dataSourceType',
    'attachmentType': '附件文件类型',  # 列表
    'liableManId': '负责人ID',
    'ourMainSignOrgId': '_ourMainSignOrgId',
    'liableManPhone': '负责人电话',
    'liableManEmail': '负责人邮箱',
    'liableManName': '合约负责人名字',
    'companyId': '_companyId',
    'effectiveRemark': '_effectiveRemark',
    'identification': '_identification',
    'lockStatus': '_lockStatus',
    'authOrgName': '原始授权方名称',
    'cname': '创建者',
    'uname': '更新用户',
    'fileName': '文件名',
    'ourMainSignOrgName': '_ourMainSignOrgName',
    'ourSignName': '_ourSignName',
    'attachmentFiles': '附件文件数据',
    'brandId': '所属厂牌ID',
    'brandName': '所属厂牌全称',
    'brandDisplayName': '所属厂牌显示名称',
    'brandCode': '所属厂牌CODE',
}

# 支付单列表
SETTLEMENT_PAYMENT_DOCUMENT_LIST_FIELDS = {
    'accountName': '收款方名字',
    'accountNum': '收款方银行账号',
    'bankName': '收款方开户行名字',
    'bfDeDepositBalance': '扣减前保底金余额',
    'bfDeOtherAmountBalance': '扣减前其他费用余额',
    'cname': '创建者',
    'code': '支付单CODE',
    'confirmInfo': '_confirmInfo',
    'confirmStatus': '_confirmStatus',
    'contractCode': '内部合同Code',
    'contractId': '内部合同ID',
    'contractName': '内部合同名称',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethodName': '合作模式名字',
    'endTime': '结算结束时间',
    'id': '支付单Id',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '支付单名称',
    'ogTotleAmount': '原始分成总计',
    'payTotleAmount': '实际分成合计',
    'paymentAttachments': '支付单附件',  # 支付单附件 一个包含字典的列表
    'paymentInvoiceAttachments': '_paymentInvoiceAttachments',
    'paymentReceiptAttachments': '_paymentReceiptAttachments',
    'settleFormula': '结算公式',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareAchievedAmount': '_shareAchievedAmount',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'sid': '_sid',
    'sstatus': '_sstatus',
    'shareInterval': '_shareInterval',
    'status': '状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 删除的内容
    # 'divisionMethod': '合作模式Id',
    # 20241101 添加的内容
    'divisionRuleId': '_divisionRuleId',
    'divisionModeNames': '_divisionModeNames',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'bname': '_bname',
    'fname': '_fname',
    'zname': '_zname',
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'settlePaymentProofGenerationStatus': '_settlePaymentProofGenerationStatus',
    # 20250415 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
}

# 支付单详情
SETTLEMENT_PAYMENT_DOCUMENT_DETAIL_FIELDS = {
    'accountName': '收款方名字',
    'accountNum': '收款方银行账号',
    'bankName': '收款方开户行名字',
    'bfDeDepositBalance': '扣减前保底金余额',
    'bfDeOtherAmountBalance': '扣减前其他费用余额',
    'cname': '创建者',
    'code': '支付单CODE',
    'confirmInfo': '_confirmInfo',
    'confirmStatus': '_confirmStatus',
    'contractCode': '内部合同Code',
    'contractId': '内部合同ID',
    'contractName': '内部合同名称',
    'contractOfflineCode': '内部合同编号',
    'contractStatus': '内部合同编号状态',
    'cpDisplayName': '所属公司显示名字',
    'cpId': '所属公司Id',
    'cpName': '所属公司名字',
    'ctime': '创建时间',
    'deDeposit': '扣减保底金',
    'deOtherAmount': '扣减其他费用',
    'divisionMethodName': '合作模式名字',
    'endTime': '结算结束时间',
    'id': '支付单Id',
    'isCanApprove': '可以审核',
    'liableManName': '合约负责人',
    'name': '支付单名称',
    'ogTotleAmount': '原始分成总计',
    'payTotleAmount': '实际分成合计',
    'paymentAttachments': '支付单附件',  # 支付单附件 一个包含字典的列表
    'paymentInvoiceAttachments': '_paymentInvoiceAttachments',
    'paymentReceiptAttachments': '_paymentReceiptAttachments',
    'settleFormula': '结算公式',
    'settlementCurrency': '结算货币ID',
    'settlementCurrencyStr': '结算货币名字',
    'shareAchievedAmount': '_shareAchievedAmount',
    'shareProportion': '合同分成比例',
    'spDisplayName': '结算渠道显示名字',
    'spId': '结算渠道Id',
    'spName': '结算渠道名字',
    'startTime': '结算开始时间',
    'sid': '_sid',
    'sstatus': '_sstatus',
    'shareInterval': '_shareInterval',
    'status': '状态',
    'statusStr': '当前状态名字',
    'supplierDisplayName': '供应商显示名字',
    'supplierId': '供应商ID',
    'supplierName': '供应商名字',
    'totleAmount': '实际分成合计',
    'uname': '更新用户',
    'utime': '更新时间',
    # 20241101 删除的内容
    # 'divisionMethod': '合作模式Id',
    # 20241101 添加的内容
    'divisionRuleId': '_divisionRuleId',
    'divisionModeNames': '_divisionModeNames',  # 内容是一个文本列表
    'shareProportions': '分成比例',  # 内容是一个百分比文本列表
    'bname': '_bname',
    'fname': '_fname',
    'zname': '_zname',
    'copyrightTypeRecord': '_copyrightTypeRecord',
    'copyrightTypeLyric': '_copyrightTypeLyric',
    'copyrightTypeMusic': '_copyrightTypeMusic',
    'copyrightTypeMv': '_copyrightTypeMv',
    'minPayBalance': '_minPayBalance',
    'otherFeeBalance': '_otherFeeBalance',
    'settlePaymentProofGenerationStatus': '_settlePaymentProofGenerationStatus',
    # 20250415 添加
    'preNegativeSettleAmount': '_preNegativeSettleAmount',
    'negativeSettleDeductedAmount': '_negativeSettleDeductedAmount',
}

# 歌曲列表
SONG_LIST_FIELDS = {
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'albumCode': '专辑CODE',
    'albumCopyrightOrgId': '专辑版权公司ID',
    'albumCopyrightOrgName': '专辑版权公司名称',
    'albumId': '专辑ID',
    'albumName': '专辑名字',
    'albumSingers': '专辑演唱者列表',  # 列表数据 None
    'albumStatus': '专辑状态',
    'arrangers': '编曲人列表',  # 列表数据
    'artistIdentities': '_artistIdentities',
    'awardRecord': '_awardRecord',
    'cd': 'CD集',
    'channelStatus': '渠道方状态',
    'cid': '创建者ID',
    'claimRemark': '_claimRemark',
    'clineOrgId': '_clineOrgId',
    'clineYear': '专辑CLine年份',
    'cname': '创建者',
    'code': 'CODE',
    'collectionName': '_collectionName',
    'collectionTranslatedName': '_collectionTranslatedName',
    'composers': '曲作者',  # 列表数据
    'copyFromSongId': '_copyFromSongId',
    'copyrightMark': '_copyrightMark',
    'creationBackground': '歌曲创作背景',
    'ctime': '创建时间',
    'customJson': '_customJson',
    'dataSourceType': '_dataSourceType',
    'dataSourceUk': '_dataSourceUk',
    'firstPublishDate': '首次发行时间',
    'hasPublicity': '_hasPublicity',
    'id': '歌曲ID',  # 改为 song_id
    'introduction': '歌曲简介',
    'isbn': 'ISBN',
    'isrc': 'ISRC',
    'iswc': 'ISWC',
    'langTags': '歌曲语言列表',  # 列表数据
    'languageTagId': '歌曲语言ID',
    'liableManId': '负责人ID',
    'liableManName': '负责人名字',
    'lockStatus': '_lockStatus',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',  # 列表数据
    'lyricCopyrightIds': '_lyricCopyrightIds',
    'lyricists': '词作者列表',  # 列表数据
    'mainTune': '_mainTune',
    'movieName': '影视名',
    'musicCopyrightContracts': '_musicCopyrightContracts',  # 列表数据
    'musicCopyrightIds': '_musicCopyrightIds',
    'name': '歌曲名称',
    'originalSingName': '_originalSingName',
    'originalSongName': '_originalSongName',
    'osSongInfo': '_osSongInfo',
    'otherTags': '歌曲标签列表',  # 列表数据
    'paymentPattern': '_paymentPattern',
    'plineOrgId': '_plineOrgId',
    'plineYear': '_plineYear',
    'presaleTime': '_presaleTime',
    'productOrgId': '制作公司ID',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'publishDate': '期望上线时间',
    'quality': '_quality',
    'reason': '_reason',
    'recordArtists': '_recordArtists',  # 列表数据
    'recordCopyrightContracts': '_recordCopyrightContracts',  # 列表数据
    'recordOrgId': '录音公司ID',
    'remixArtists': '_remixArtists',  # 列表数据
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'selfOwn': '_selfOwn',
    'sendType': '_sendType',
    'singers': '演唱者列表',  # 列表数据
    'songSource': '歌曲来源',
    'sort': '排序',
    'soundRecordingCopyrightIds': '_soundRecordingCopyrightIds',
    'source': '_source',
    'status': '状态',
    'styleTagId': '歌曲风格ID',
    'styleTags': '歌曲风格列表',  # 列表数据
    'subtitle': '歌曲副标题',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'trackNum': '音轨号',
    'translatedName': '歌曲译名',
    'type': '类型',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': '唯一名称',
    'upCpSongNo': '_upCpSongNo',
    'utime': '更新时间',
    'version': '版本列表',  # 列表
    'versionName': '版本名字',
    'visrc': '虚拟ISRC',
    # 20250415 添加
    'supplierAuth': '_supplierAuth',
    'authOrgList': '_authOrgList',  # 列表数据
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
}

# 歌曲详情
SONG_DETAIL_FIELDS = {
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'albumCode': '专辑CODE',
    'albumCopyrightOrgId': '专辑版权公司ID',
    'albumCopyrightOrgName': '专辑版权公司名称',
    'albumId': '专辑ID',
    'albumName': '专辑名字',
    'albumSingers': '专辑演唱者列表',  # 列表数据
    'albumStatus': '专辑状态',
    'arranger': '编曲',  # 列表数据
    'arrangers': '编曲人列表',  # 列表数据
    'artistIdentities': '_artistIdentities',
    'authRegionIds': '_authRegionIds',
    'awardRecord': '_awardRecord',
    'cd': 'CD集',
    'cdId': 'CD集ID',
    'cdName': 'CD集名字',
    'cdNo': 'CD集号码',
    'channelArtists': '渠道方演唱者列表',  # 列表数据
    'channelIdInfos': '渠道方歌曲信息列表',  # 列表数据
    'channelStatus': '渠道方状态',
    'cid': '创建者ID',
    'claimRemark': '_claimRemark',
    'clineOrgDisplayName': '_clineOrgDisplayName',
    'clineOrgId': '_clineOrgId',
    'clineOrgName': '_clineOrgName',
    'clineOrgStatus': '_clineOrgStatus',
    'clineYear': '专辑CLine年份',
    'cname': '创建者',
    'code': 'CODE',
    'collectionName': '_collectionName',
    'collectionTranslatedName': '_collectionTranslatedName',
    'composer': '曲作者',  # 列表数据
    'composers': '曲作者列表',  # 列表数据
    'copyFromSongId': '_copyFromSongId',
    'copyrightMark': '_copyrightMark',
    'creationBackground': '歌曲创作背景',
    'ctime': '创建时间',
    'customJson': '_customJson',
    'dataSourceType': '_dataSourceType',
    'dataSourceUk': '_dataSourceUk',
    'firstPublishDate': '首次发行时间',
    'hasPublicity': '_hasPublicity',
    'haveAllCopyright': '_haveAllCopyright',
    'id': '歌曲ID',  # 改为 song_id
    'introduction': '歌曲简介',
    'isbn': 'ISBN',
    'isrc': 'ISRC',
    'isrcEditFlag': '_isrcEditFlag',
    'iswc': 'ISWC',
    'langTags': '歌曲语言列表',  # 列表数据
    'languageTagId': '歌曲语言ID',
    'liableManId': '负责人ID',
    'liableManName': '负责人名字',
    'lockStatus': '_lockStatus',
    'lyricCopyrightContracts': '_lyricCopyrightContracts',  # 列表数据
    'lyricCopyrightIds': '_lyricCopyrightIds',
    'lyricist': '词作者',  # 列表数据
    'lyricists': '词作者列表',  # 列表数据
    'lyrics': '歌词',
    'mainTune': '_mainTune',
    'movieName': '影视名',
    'musicCopyrightContracts': '_musicCopyrightContracts',  # 列表数据
    'musicCopyrightIds': '_musicCopyrightIds',
    'name': '歌曲名称',
    'offlineDate': '_offlineDate',
    'onlineDate': '_onlineDate',
    'originalSingName': '_originalSingName',
    'originalSongName': '_originalSongName',
    'osSongInfo': '_osSongInfo',
    'otherTags': '歌曲标签列表',  # 列表数据
    'overseasLyrics': '海外歌词列表',  # 列表数据'
    'paymentPattern': '_paymentPattern',
    'plineOrgDisplayName': '_plineOrgDisplayName',
    'plineOrgId': '_plineOrgId',
    'plineOrgName': '_plineOrgName',
    'plineOrgStatus': '_plineOrgStatus',
    'plineYear': '_plineYear',
    'presaleTime': '_presaleTime',
    'producers': '制作人列表',  # 列表数据
    'productOrgId': '制作公司ID',
    'productOrgName': '制作公司',
    'productOrgStatus': '制作公司状态',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'publishDate': '期望上线时间',
    'quality': '_quality',
    'reason': '_reason',
    'recordArtists': '_recordArtists',  # 列表数据
    'recordCopyrightContracts': '_recordCopyrightContracts',  # 列表数据
    'recordOrgDisplayName': '录音公司常用名',
    'recordOrgId': '录音公司ID',
    'recordOrgName': '录音公司全称',
    'recordOrgStatus': '录音公司状态',
    'recordingCopyright': '_recordingCopyright',
    'remixArtists': '_remixArtists',  # 列表数据
    'rightPercentage': '_rightPercentage',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'selfOwn': '_selfOwn',
    'sendType': '_sendType',
    'singers': '演唱者列表',  # 列表数据
    'songLyricCopyrights': '_songLyricCopyrights',
    'songMaterialVo': '_songMaterialVo',
    'songMusicCopyrights': '_songMusicCopyrights',
    'songProducers': '_songProducers',
    'songSource': '歌曲来源',
    'sort': '排序',
    'soundRecordingCopyrightIds': '_soundRecordingCopyrightIds',
    'source': '_source',
    'speptVos': '渠道列表',  # 列表数据
    'status': '状态',
    'styleTagId': '歌曲风格ID',
    'styleTags': '歌曲风格列表',  # 列表数据
    'subtitle': '歌曲副标题',
    'takeDown': '_takeDown',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'tmeEpId': 'TME生态歌曲ID',
    'tmeTrackId': 'TME音轨ID',
    'trackNum': '音轨号',
    'translatedName': '歌曲译名',
    'type': '类型',
    'uid': '更新用户ID',
    'uname': '更新用户',
    'uniqueName': '唯一名称',
    'upCpSongNo': '_upCpSongNo',
    'utime': '更新时间',
    'version': '版本列表',  # 列表
    'versionName': '版本名字',
    'visrc': '虚拟ISRC',
    'visrcEditFlag': '_visrcEditFlag',
    # 20250415 添加
    'supplierAuth': '_supplierAuth',
    'authOrgList': '_authOrgList',  # 列表数据
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
}

# 专辑列表
ALBUM_LIST_FIELDS = {
    'id': '专辑ID',
    'name': '专辑名称',
    'translatedName': '专辑译名',
    'type': '专辑类型',
    'version': '专辑版本',
    'upc': 'UPC',
    'publishDate': '期望上线时间',
    'firstPublishDate': '首次发行时间',
    'selfOwn': '_selfOwn',
    'copyrightOwnerId': '_copyrightOwnerId',
    'recordCompanyId': '_recordCompanyId',
    'source': '_source',
    'introduction': '_introduction',
    'upAlbumId': '_upAlbumId',
    'upRequireOffDate': '_upRequireOffDate',
    'paymentPattern': '_paymentPattern',
    'abroadDocument': '_abroadDocument',
    'cid': '创建者ID',
    'uid': '更新用户ID',
    'ctime': '创建时间',
    'utime': '更新时间',
    'status': '状态',
    'code': 'CODE',
    'languageTagId': '歌曲语言ID',
    'styleTagId': '歌曲风格ID',
    'uniqueName': '唯一名称',
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'dataSourceType': '_dataSourceType',
    'albumArea': '_albumArea',
    'versionName': '版本名字',
    'presaleTime': '_presaleTime',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'dataSourceUk': '_dataSourceUk',
    'hasPublicity': '_hasPublicity',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'originalCopyrightOwnerId': '_originalCopyrightOwnerId',
    'isStockAlbum': '_isStockAlbum',
    'tmeEpId': 'TME生态歌曲ID',
    'vupc': '虚拟UPC',
    'supplierAuth': '_supplierAuth',
    'platformType': '_platformType',
    'supplierStatus': '_supplierStatus',
    'supplierOrgId': '_supplierOrgId',
    'albumImages': '_albumImages',
    'albumAbroadImages': '_albumAbroadImages',
    'albumAbroadImage': '_albumAbroadImage',
    'albumImage': '_albumImage',
    'copyrightOwnerName': '_copyrightOwnerName',
    'copyrightOwnerDisplayName': '_copyrightOwnerDisplayName',
    'copyrightOwnerCode': '_copyrightOwnerCode',
    'copyrightOwnerStatus': '_copyrightOwnerStatus',
    'recordCompanyName': '_recordCompanyName',
    'recordCompanyDisplayName': '_recordCompanyDisplayName',
    'recordCompanyStatus': '_recordCompanyStatus',
    'singers': '演唱者列表',
    'lang': '语言列表',
    'style': '风格列表',
    'tags': '_tags',
    'cname': '创建者',
    'uname': '更新用户',
    'auditId': '_auditId',
    'auditStatus': '_auditStatus',
    'auditUtime': '_auditUtime',
    'orgType': '_orgType',
    'orgName': '_orgName',
    'orgDisplayName': '_orgDisplayName',
    'attachmentFiles': '附件文件数据',
    'channelIdInfos': '渠道方歌曲信息列表',
    'originalCopyrightOwnerName': '_originalCopyrightOwnerName',
    'originalCopyrightOwnerDisplayName': '_originalCopyrightOwnerDisplayName',
    'originalCopyrightOwnerStatus': '_originalCopyrightOwnerStatus',
    'songPublishDate': '_songPublishDate',
    'albumSongNum': '_albumSongNum',
    'authOrgList': '_authOrgList',
    'ourSignOrgList': '_ourSignOrgList',
    'sourceType': '_sourceType',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'plineDisplayName': '专辑PLine显示名字',
    'plineStatus': '专辑PLine状态',
    'clineDisplayName': '专辑CLine显示名字',
    'clineStatus': '专辑CLine状态',
    'clineName': '专辑CLine公司名字',
    'plineName': '专辑PLine公司名字',
    'lockOrgId': '_lockOrgId',
    'clineYear': '专辑CLine年份',
    'clineOrgId': '专辑CLine公司ID',
    'plineYear': '专辑PLine年份',
    'plineOrgId': '专辑PLine公司ID',
}

# 专辑详情
ALBUM_DETAIL_FIELDS = {
    'id': '专辑ID',
    'name': '专辑名称',
    'translatedName': '专辑译名',
    'type': '专辑类型',
    'version': '专辑版本',
    'upc': 'UPC',
    'publishDate': '期望上线时间',
    'firstPublishDate': '首次发行时间',
    'selfOwn': '_selfOwn',
    'copyrightOwnerId': '_copyrightOwnerId',
    'recordCompanyId': '_recordCompanyId',
    'source': '_source',
    'introduction': '_introduction',
    'upAlbumId': '_upAlbumId',
    'upRequireOffDate': '_upRequireOffDate',
    'paymentPattern': '_paymentPattern',
    'abroadDocument': '_abroadDocument',
    'cid': '创建者ID',
    'uid': '更新用户ID',
    'ctime': '创建时间',
    'utime': '更新时间',
    'status': '状态',
    'code': 'CODE',
    'languageTagId': '歌曲语言ID',
    'styleTagId': '歌曲风格ID',
    'uniqueName': '唯一名称',
    'advertPublishBeginDate': '_advertPublishBeginDate',
    'advertPublishEndDate': '_advertPublishEndDate',
    'tmeCmlId': 'TME中央曲库歌曲ID',
    'dataSourceType': '_dataSourceType',
    'albumArea': '_albumArea',
    'versionName': '版本名字',
    'presaleTime': '_presaleTime',
    'saleBeginTime': '销售开始时间',
    'saleEndTime': '销售结束时间',
    'salePrice': '销售价钱',
    'dataSourceUk': '_dataSourceUk',
    'hasPublicity': '_hasPublicity',
    'publicityPaymentPattern': '_publicityPaymentPattern',
    'originalCopyrightOwnerId': '_originalCopyrightOwnerId',
    'isStockAlbum': '_isStockAlbum',
    'tmeEpId': 'TME生态歌曲ID',
    'vupc': '虚拟UPC',
    'supplierAuth': '_supplierAuth',
    'platformType': '_platformType',
    'supplierStatus': '_supplierStatus',
    'supplierOrgId': '_supplierOrgId',
    'albumImages': '_albumImages',
    'albumAbroadImages': '_albumAbroadImages',
    'albumAbroadImage': '_albumAbroadImage',
    'albumImage': '_albumImage',
    'copyrightOwnerName': '_copyrightOwnerName',
    'copyrightOwnerDisplayName': '_copyrightOwnerDisplayName',
    'copyrightOwnerCode': '_copyrightOwnerCode',
    'copyrightOwnerStatus': '_copyrightOwnerStatus',
    'recordCompanyName': '_recordCompanyName',
    'recordCompanyDisplayName': '_recordCompanyDisplayName',
    'recordCompanyStatus': '_recordCompanyStatus',
    'singers': '演唱者列表',  # 列表数据
    'lang': '语言列表',  # 列表数据
    'style': '风格列表',  # 列表数据
    'tags': '_tags',
    'cname': '创建者',
    'uname': '更新用户',
    'auditId': '_auditId',
    'auditStatus': '_auditStatus',
    'auditUtime': '_auditUtime',
    'orgType': '_orgType',
    'orgName': '_orgName',
    'orgDisplayName': '_orgDisplayName',
    'attachmentFiles': '附件文件数据',  # 列表数据
    'channelIdInfos': '渠道方歌曲信息列表',  # 列表数据
    'originalCopyrightOwnerName': '_originalCopyrightOwnerName',
    'originalCopyrightOwnerDisplayName': '_originalCopyrightOwnerDisplayName',
    'originalCopyrightOwnerStatus': '_originalCopyrightOwnerStatus',
    'songPublishDate': '_songPublishDate',
    'albumSongNum': '_albumSongNum',
    'authOrgList': '_authOrgList',  # 列表数据
    'ourSignOrgList': '_ourSignOrgList',  # 列表数据
    'sourceType': '_sourceType',
    'editLock': '_editLock',
    'editLockOrgName': '_editLockOrgName',
    'upAlbumName': '_upAlbumName',
    'songLyricFileVos': '_songLyricFileVos',
    'confirmParam': '_confirmParam',
    'onlineDate': '_onlineDate',
    'offlineDate': '_offlineDate',
    'authRegionType': '_authRegionType',
    'authRegions': '_authRegions',
    'tmeAlbumId': 'TME专辑ID',
    'odAlbumId': '_odAlbumId',
    'upcEditFlag': '_upcEditFlag',
    'vupcEditFlag': '_vupcEditFlag',
    'speptVos': '_speptVos',
    'plineDisplayName': '专辑PLine显示名字',
    'plineStatus': '专辑PLine状态',
    'clineDisplayName': '专辑CLine显示名字',
    'clineStatus': '专辑CLine状态',
    'clineName': '专辑CLine公司名字',
    'plineName': '专辑PLine公司名字',
    'lockOrgId': '_lockOrgId',
    'clineYear': '专辑CLine年份',
    'clineOrgId': '专辑CLine公司ID',
    'plineYear': '专辑PLine年份',
    'plineOrgId': '专辑PLine公司ID',
}



"""
阔景版权服务平台

网址：https://ds.kuojingyueyi.cn/app/index

注：上传文件需要 requests-toolbelt
"""

import os
import json
import time
import hashlib
import random
from pathlib import Path
from pprint import pprint as pp

import requests

from requests import Response
# from requests_toolbelt import MultipartEncoder
from urllib.parse import urlparse, unquote

from .utils import need_login, BaseClient
from .exception import LoginError, NeedAccessTokenException

HEADERS_JSON = {
    'authorization': '',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.198 Safari/537.36',
    'content-type': 'application/json;charset=UTF-8',
    'accept-language': 'zh-CN,zh;q=0.9'
}


class KuoJingYueYi(BaseClient):

    def __init__(self, base_url='https://ds.kuojingyueyi.cn', *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.base_url = base_url
        self.set_headers(HEADERS_JSON)
        self.data = {}
        self._access_token = None

    def set_access_token(self, access_token):
        """
        设置用户授权
        """
        HEADERS_JSON['authorization'] = access_token
        self.set_headers(HEADERS_JSON)
        # 我们获取消息数量，检查是否已经登录成功

        self._access_token = access_token

    def need_access_token(self):
        """
        检查是否已登录，我们还是只简单检查有没有 access_token
        """
        # self.get_count_message()
        if self._access_token is None:
            raise NeedAccessTokenException()

    def get_response_data(self, resp):
        """
        解析接口返回的数据
        """
        try:
            self.data = resp.json()
        except Exception as e:
            return {
                "code": 88888888,
                "data": {
                    "description": f"转换json数据失败：{e}",
                    "error_code": 88888888,
                }
            }

        # 我们不检查信息是否错误，在获取信息的时候在检查
        # if self.data['code'] != 200:
        #     raise ValueError(f'{self.data}')

        return self.data

    def un_read_count(self):
        """
        获取未读信息数量

        用来检查登录状态
        response_data = k.un_read_count()
        pp(response_data)
        if response_data['code'] == 401:
            print(f'用户登录失败：{response_data["data"]}')
        elif response_data['code'] != 200:
            print(f'发生未知错误：{response_data["data"]}')
        """
        url = f"{self.base_url}/api/admin/inner-message/unReadCount"
        r = self._session.get(url)
        return self.get_response_data(r)

    def personal_center_my_detail(self):
        """
        用户信息（当前登录账户）

        个人中心/我的信息
        网址: https://ds.kuojingyueyi.cn/app/center/info
        """
        url = f"{self.base_url}/api/admin/personal-center/detail"
        r = self._session.get(url)
        return self.get_response_data(r)

    def search_org(self, name, org_types=None, page=1, page_size=20):
        """
        搜索他方签约主体

        # 搜索 他方签约主体：org_types = [1]
        # 搜索 结算渠道：org_types = [3]
        # 搜索 所属公司：org_types = [2, 1]

        合约管理/采购合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-list?current=1&pageSize=20&authOrg=%E5%B9%BF%E5%B7%9E%E5%A4%A9%E6%9E%9C%E6%96%87%E5%8C%96%E4%BC%A0%E6%92%AD%E6%9C%89%E9%99%90%E5%85%AC%E5%8F%B8&authOrgId=692
        """
        if org_types is None:
            org_types = [1]

        data = {
            'name': name,
            'orgTypes': org_types
        }
        url = f"{self.base_url}/api/admin/dict/org/search?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=data)
        return self.get_response_data(r)

    def contract_manage_cp_list(self, page=1, page_size=20, **kwargs):
        """
        采购合约列表

        合约管理/采购合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-list/?current=1&pageSize=20&offlineCode=SZQY-CGDL-20180401-200--051

        # 支持的参数
        "pageNo": 2,  # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        # 内部合约编号
        "offlineCode": "SZQY-CGDL-20180401-200--051"
        """
        # print(kwargs)
        url = f"{self.base_url}/api/admin/cp-contract/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    # def search_contract_song(self, pk, copyright_type=3, page=1, page_size=20):
    #     """
    #     采购合约关联歌曲
    #
    #     合约管理/采购合约
    #     网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-view/5219?status=3&tab=related_songs
    #
    #     :param pk: 合同ID
    #     """
    #     data = {
    #         "contractId": pk,  # 合同ID
    #         "copyrightType": copyright_type  # 版权类型 1 词版权 2 曲版权 3 录音版权
    #     }
    #     url = f"{self.base_url}/api/admin/cp-contract/search-relate-song?pageNo={page}&pageSize={page_size}"
    #     r = self._session.post(url, json=data)
    #     return self.get_response_data(r)

    def get_cp_contract_work_list(self, pk, page=1, page_size=20):
        """
        采购合约-合约作品清单

        合约管理/采购合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-view/1104?tab=related_songs

        :param pk: 合同ID
        """
        data = {
            "contractId": pk,  # 合同ID
        }
        url = f"{self.base_url}/api/admin/cp-contract/work/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=data)
        return self.get_response_data(r)

    def get_cp_contract_work_related_unbound(self, pk, page=1, page_size=20):
        """
        采购合约-合约关联的作品(已入库但未在合约作品清单中)

        合约管理/采购合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-view/1104?tab=related_songs

        :param pk: 合同ID
        """
        data = {
            "contractId": pk,  # 合同ID
        }
        url = f"{self.base_url}/api/admin/cp-contract/work/related/unbound/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=data)
        return self.get_response_data(r)

    def get_cp_contract_detail(self, pk):
        """
        采购合约详情

        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-view/17594?status=1

        :param pk: 采购合约ID
        """
        url = f"{self.base_url}/api/admin/cp-contract/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def get_cp_contract_detail_copyright(self, pk):
        """
        采购合约-版权信息

        网址:

        :param pk: 采购合约ID
        """
        url = f"{self.base_url}/api/admin/cp-contract/detail-copyright/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def get_cp_contract_detail_settlement_list_mode(self, pk):
        """
        采购合约-结算模式

        网址:

        :param pk: 采购合约ID
        """
        url = f"{self.base_url}/api/admin/cp-contract/detail-settlement-mode-list/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def get_cp_contract_detail_settlement(self, pk):
        """
        采购合约-结算信息

        网址:

        :param pk: 采购合约ID
        """
        url = f"{self.base_url}/api/admin/cp-contract/detail-settlement/list/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def export_contract_data(self, pk, save_file=None, data_type=None, mode=1, type_int=70):
        """
        导出数据采购合约数据（文件）

        合约管理/采购合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/cp-view/17961?status=3&tab=related_songs

        :param pk: 合同ID
        """
        if data_type is None:
            data_type = [1]

        data = {
            'dataType': data_type,
            'mode': mode,
            'paramJson': json.dumps({"contractId": str(pk)}, ),
            'type': type_int
        }

        url = f"{self.base_url}/api/admin/common/export/exportExcelOrTask"
        r = self._session.post(url, json=data, stream=True)

        if r.status_code == 200:
            if save_file is None:
                # 从响应头中提取文件名
                content_disposition = r.headers.get('Content-Disposition')
                if content_disposition:
                    filename_encoded = content_disposition.split('filename=')[-1].strip('\"')
                    filename = unquote(filename_encoded)  # 解码URL编码的文件名
                    save_file = f"{pk}_{os.path.basename(filename)}"  # 确保文件名是安全的
                else:
                    save_file = f'{pk}.xlsx'  # 默认文件名

            temp_save_file = save_file + ".tmp"
            try:
                # 保存文件
                with open(temp_save_file, 'wb') as file:
                    file.write(r.content)

                os.rename(temp_save_file, save_file)
                print(f"下载文件成功: {save_file}")
            except Exception as e:
                if os.path.exists(temp_save_file):
                    os.remove(temp_save_file)
                print(f"保存文件失败，已删除临时文件: {e}")
            return save_file
        else:
            print(f"访问错误: {r.status_code}")

    def contract_manage_sp_list(self, page=1, page_size=20, **kwargs):
        """
        售卖合约列表

        合约管理/售卖合约
        网址: https://ds.kuojingyueyi.cn/app/contract-manage/sp-list?current=1&pageSize=20

        # 支持的参数
        "pageNo": 2,  # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        "status": '',  # 可不用

        # 内部合约编号
        offlineCode: "CON02-TME00-20241216-0035"
        """
        # print(kwargs)
        url = f"{self.base_url}/api/admin/sp-contract/search?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    def get_sp_contract_detail(self, pk):
        """
        售卖合约详情

        网址: https://ds.kuojingyueyi.cn/app/contract-manage/sp?contractId=25165

        :param pk: 售卖合约ID
        """
        url = f"{self.base_url}/api/admin/sp-contract/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def settlement_supplier_document(self, page=1, page_size=20, **kwargs):
        """
        供应商结算单

        结算管理/供应商结算单
        网址: https://ds.kuojingyueyi.cn/app/settle-manage/supplier-bill-manage?current=1&pageSize=20&contractIdOrName=QHKJ-WTZZ

        # 支持的参数
        "pageNo": 2,  # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        # 合同ID/编号/名称
        contractIdOrName: "QHKJ-WTZZ"
        """
        # print(kwargs)
        # https://ds.kuojingyueyi.cn/api/admin/settlement-supplier-document/list?pageNo=1&pageSize=20
        url = f"{self.base_url}/api/admin/settlement-supplier-document/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    def supplier_bill_detail(self, pk):
        """
        供应商结算单-详情

        供应商结算单/查看详情
        网址: https://ds.kuojingyueyi.cn/app/settle-manage/supplier-bill-detail/196

        :param pk: 结算单ID
        """
        url = f"{self.base_url}/api/admin/settlement-supplier-document/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def supplier_bill_audit_approve(self, ids, status=0, approve='通过', msg=None):
        """
        供应商结算单-审核

        合约管理/供应商结算单
        网址: https://ds.kuojingyueyi.cn/app/app/settle-manage/supplier-bill-audit/196
        # status: 5 是当前审核状态 statusStr: "审核完成" 是状态描述
        # 可以通过 isCanApprove 来判断是否可以审核，"审核完成"和"驳回"的就算可以审核 再审核也没有意义
        # frozenStatus: 0 有审核权限的时候他也会影响审核按钮的状态 0 可以审核 1 禁止审核
        """
        # http://bq-test.karakal.com.cn:18100/api/admin/
        data = {
            "batchAudit": False,  # 批量审核
            "currentStatus": status,  # 0 初审 1 业务审核 2 复核 3 财务审核 > 流程结束
            "result": 1,  # 1 通过 0 不通过
            "supplierDocIds": ids,
            'msg': msg
        }

        if approve == '通过':
            data['result'] = 1
        else:
            data['result'] = 0
            if not msg:
                raise ValueError('请输入审批描述')

        if len(ids) > 1:
            data['batchAudit'] = True
        else:
            data['batchAudit'] = False

        url = f"{self.base_url}/api/admin/settlement-supplier-document/approve"
        r = self._session.post(url, json=data)
        return self.get_response_data(r)

    def settlement_payment_document_list(self, page=1, page_size=20, **kwargs):
        """
        支付单列表

        结算管理/支付单
        网址: https://ds.kuojingyueyi.cn/app/settle-manage/pay-bill-manage?current=1&pageSize=20

        # 支持的参数
        "pageNo": 2,  # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        # 内部合约编号
        "docIdOrName": "P724_20230401_20230930_Z16OXKY"
        """
        # https://ds.kuojingyueyi.cn/api/admin//list?pageNo=1&pageSize=20
        # print(kwargs)
        url = f"{self.base_url}/api/admin/settlement-payment-document/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    def settlement_payment_document_detail(self, pk):
        """
        支付单详情

        结算管理/支付单/支付单信息
        网址: https://ds.kuojingyueyi.cn/app/settle-manage/pay-bill-detail/3682

        :param pk: 支付单ID
        """
        url = f"{self.base_url}/api/admin/settlement-payment-document/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def song_list(self, page=1, page_size=20, **kwargs):
        """
        歌曲列表

        内容管理/歌曲管理
        网址: https://ds.kuojingyueyi.cn/app/content-manage/song-manage?current=1&pageSize=20

        # 支持的参数
        'queryType': 1,  # 可不用
        'pageNo': 1,   # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        """
        # print(kwargs)
        url = f"{self.base_url}/api/admin/song/list?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    def song_detail(self, pk):
        """
        歌曲详情

        歌曲管理/查看详情
        网址: https://ds-test.kuojingyueyi.cn/app/content-manage/song/detail/233616?status=1&albumId=73812

        :param pk: 歌曲ID
        """
        url = f"{self.base_url}/api/admin/song/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)

    def album_list(self, page=1, page_size=20, **kwargs):
        """
        专辑列表

        内容管理/专辑管理
        网址: https://ds.kuojingyueyi.cn/app/content-manage/album-manage?current=1&pageSize=20

        # 支持的参数
        'queryType': 1,  # 可不用
        'pageNo': 1,   # 可不用
        "current": 1,  # 可不用
        "pageSize": 20,  # 可不用
        """
        # print(kwargs)
        url = f"{self.base_url}/api/admin/album/search?pageNo={page}&pageSize={page_size}"
        r = self._session.post(url, json=kwargs)
        return self.get_response_data(r)

    def album_detail(self, pk):
        """
        专辑详情

        专辑管理/查看详情
        网址: https://ds.kuojingyueyi.cn/app/content-manage/album/detail/73617?status=4

        :param pk: 专辑ID
        """
        url = f"{self.base_url}/api/admin/album/detail/{pk}"
        r = self._session.get(url)
        return self.get_response_data(r)
